OdaLightCurve
=============

.. currentmodule:: oda_api.plot_tools

.. autoclass:: OdaLightCurve
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~OdaLightCurve.show

   .. rubric:: Methods Documentation

   .. automethod:: show
